@@ -94,7 +94,7 @@ class TestCase(testtools.TestCase):
 
 class FakeNLRI(object):
 
-    def __init__(self, nlri_desc, afi=1, safi=1):
+    def __init__(self, nlri_desc, afi=exa.AFI.ipv4, safi=exa.SAFI.mpls_vpn):
         self.nlri = nlri_desc
         self.afi = afi
         self.safi = safi
@@ -108,8 +108,8 @@ class BaseTestBagPipeBGP(object):
     def set_event_target_worker(self, worker):
         self.event_target_worker = worker
 
-    def _fake_nlri(self, fake_nlri_desc):
-        return FakeNLRI(fake_nlri_desc)
+    def _fake_nlri(self, fake_nlri_desc, **kwargs):
+        return FakeNLRI(fake_nlri_desc, **kwargs)
 
     def _new_route_event(self, event_type, nlri, rts, source, nh, lp=0,
                          replaced_route_entry=None,
